# ** Sedna: A Python Package for computational mathematics, and more.. **

Sedna is an all-in-one python package which is designed to meet your needs. It contains various modules such as maths, physics, prime, system and voice in order to create a versatile experience.

You can read information about each of the functions by reading the comments provided.

To start:

```
pip install sedna
```

We are bond to withold the quality of this library and keep providing updates in order to expand this library.

We will provide you with a detailed documentation of every module as soon as we are able to complete the development and release it as the first stable version.


Thanks for choosing Sedna!